(_changelog)=
# Changelog

## 2024.09.1
- Major release with large updates to the user interface

## 2024.09.0
- Fix nans in tomography grid

## 2024.08.1
- Disallow nan values in the tomography code

## 2024.08.0
- Some bug fixes in the tomography module

## 2024.06.0
- Update the internal platform module to match `skplatform` 0.2.6

## 2024.02.0
- First release with preliminary `sasktran2 support


## 0.3.0
- Last release before moving over to `sasktran2`
